<?xml version="1.0" encoding="UTF-8" ?>
<!-- This file handles variable definitions -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="UTF-8"
    doctype-system="http://www.springframework.org/dtd/spring-beans.dtd"
    doctype-public="-//SPRING//DTD BEAN//EN"
    cdata-section-elements="beans" />

  <!-- Default stage table names -->
  <xsl:variable name="ST_RECURRENT_COVERAGES">DS_RECURRENT_COVERAGES</xsl:variable>

  <!-- Staging Field names -->
  <xsl:variable name="owning_group_key_field">owning_group_key</xsl:variable>
  <xsl:variable name="coverage_name_field">coverage_name</xsl:variable>
  <xsl:variable name="start_date_field">start_date</xsl:variable>
  <xsl:variable name="start_time_field">start_time</xsl:variable>
  <xsl:variable name="duration_field">duration</xsl:variable>
  <xsl:variable name="day_pattern_field">day_pattern</xsl:variable>
  <xsl:variable name="frequency_field">frequency</xsl:variable>
  <xsl:variable name="interval_field">interval</xsl:variable>
  <xsl:variable name="include_site_holidays_field">include_site_holidays</xsl:variable>
  <xsl:variable name="recurrence_end_field">recurrence_end</xsl:variable>
  <xsl:variable name="worker_team_key_field">worker_team_key</xsl:variable>

  <!-- Group Recurring Coverages .. Table Level -->
  <xsl:template match="recurrent_coverages">
    <bean>
      <xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
      </xsl:attribute>
      <xsl:call-template name="inject_staging_datasource" />
      <xsl:call-template name="choose_staging_table_name">
        <xsl:with-param name="default_name" select="$ST_RECURRENT_COVERAGES" />
      </xsl:call-template>
      <property name="dataSynchronizationService">
        <ref bean="dataSyncGroupRecurringScheduleService" />
      </property>
      <xsl:call-template name="inject_report_keeper"/>
      <!-- Row Synchronizer -->
      <xsl:call-template name="row_synchronizer">
        <xsl:with-param name="data_synchronization_service">dataSyncGroupRecurringScheduleService</xsl:with-param>
        <xsl:with-param name="default_table" select="$ST_RECURRENT_COVERAGES" />
      </xsl:call-template>
    </bean>
  </xsl:template>
  
  <!-- Group Recurring Coverages .. Field Level -->
  <xsl:template match="owning_group_key">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">owningGroup</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncGroupService</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="coverage_name">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">scheduleName</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="start_date">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">startDate</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="start_time">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">startTime</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="duration">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">duration</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="day_pattern">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">dayPattern</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="frequency">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">frequency</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$scheduleFrequencyTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="interval">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">interval</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$integerTypeMapper" />
    </xsl:call-template>
  </xsl:template>

	<xsl:template match="include_site_holidays">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">includeSiteHolidays</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
		</xsl:call-template>
	</xsl:template>

  <xsl:template match="recurrence_end">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">recurrenceEnd</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="worker_team_key">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">workerTeam</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncTeamService</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
